========================
Django Celery Extensions
========================


.. image:: https://img.shields.io/pypi/v/django-celery-extensions.svg
        :target: https://pypi.python.org/pypi/django-celery-extensions

.. image:: https://img.shields.io/travis/druids/django-celery-extensions.svg
        :target: https://travis-ci.org/druids/django-celery-extensions

.. image:: https://readthedocs.org/projects/django-celery-extensions/badge/?version=latest
        :target: https://django-celery-extensions.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/druids/django-celery-extensions/badge.svg?branch=master
        :target: https://coveralls.io/github/druids/django-celery-extensions?branch=master
        :alt: Code coverage

General purpose celery extensions library for Django.


* Free software: MIT license
* Documentation: https://django-celery-extensions.readthedocs.io.
* Supported Python versions: 3.6, 3.7, 3.8
* Supported Django versions: 2.2


Features
--------

* Easy integration into project
* Run celery via Django
* Unique running instance of celery beater
* Unique task run
